#include "mafenetre.h"

MaFenetre::MaFenetre(QWidget *parent) :
    QWidget(parent)
{    
    // La GUI
    btInsererJeton = new QPushButton(QString::fromUtf8("Insérer jeton"), this);
    btPousser = new QPushButton(QString::fromUtf8("Pousser portillon"), this);
    labelUtilisateur = new QLabel(this);
    labelUtilisateur->setAlignment(Qt::AlignCenter);
    labelPortillon = new QLabel(this);
    labelPortillon->setAlignment(Qt::AlignCenter);
    QVBoxLayout *layout = new QVBoxLayout;
    layout->addWidget(btInsererJeton);
    layout->addWidget(btPousser);
    layout->addWidget(labelUtilisateur);
    layout->addStretch();
    layout->addWidget(labelPortillon);
    setLayout(layout);

    // La machine à état
    machine = new QStateMachine(this);

    // Les états (voir graphe)
    QState *etatVerrouille = new QState();
    etatVerrouille->assignProperty(labelPortillon, "text", QString::fromUtf8("Portillon verrouillé"));
    QState *etatDeverrouille = new QState();
    etatDeverrouille->assignProperty(labelPortillon, "text", QString::fromUtf8("Portillon déverrouillé"));
    machine->addState(etatVerrouille);
    machine->addState(etatDeverrouille);

    // Les transitions (voir graphe)
    etatVerrouille->addTransition(btInsererJeton, SIGNAL(clicked()), etatDeverrouille);
    etatDeverrouille->addTransition(btPousser, SIGNAL(clicked()), etatVerrouille);

    // Les actions
    connect(etatVerrouille, SIGNAL(entered()), this, SLOT(afficherInviteInsererJeton()));
    connect(etatVerrouille, SIGNAL(exited()), this, SLOT(afficherInvitePassage()));

    //
    machine->setInitialState(etatVerrouille);
    machine->start();
}

MaFenetre::~MaFenetre()
{
    machine->stop();
}

void MaFenetre::afficherInviteInsererJeton()
{
    labelUtilisateur->setText("Veuillez insérer un jeton");
}

void MaFenetre::afficherInvitePassage()
{
    labelUtilisateur->setText("Bonne journée !");
}
